package com.persagy.iottransfer.kafka;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.persagy.iottransfer.client.IotClient;
import com.persagy.iottransfer.communication.entity.Packet;
import com.persagy.iottransfer.communication.entity.PacketEntity;
import com.persagy.iottransfer.communication.util.IClientManager;
import lombok.extern.slf4j.Slf4j;
import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.kafka.annotation.KafkaListener;
import org.springframework.kafka.support.Acknowledgment;
import org.springframework.kafka.support.KafkaHeaders;
import org.springframework.messaging.handler.annotation.Header;
import org.springframework.stereotype.Component;

import java.util.Optional;

/**
 * @description:
 * @author:lgy
 * @data:2021/8/20 10:10
 */
@Component
@Slf4j
@ConditionalOnProperty(prefix = "iot.type",name = "cloud",havingValue = "true",matchIfMissing = false)
public class KafkaConsumerEdge2Cloud {


    @KafkaListener(topics = KafkaProducer.TOPIC_EDGE2COLLECT, groupId = KafkaProducer.TOPIC_CLOUD)
    public void topicEdge2Collect(ConsumerRecord<String, String> record, Acknowledgment ack, @Header(KafkaHeaders.RECEIVED_TOPIC) String topic) {
        Optional<String> message = Optional.ofNullable(record.value());
        try {
            if (message.isPresent()) {
                String msg = message.get();
                log.info("topic iot.edge2collect------消费了： Topic:" + topic + ",Message:" + msg);
                PacketEntity packetEntity = JSONObject.parseObject(msg, PacketEntity.class);
                IClientManager clientManager = IotClient.clientproject2CollectManagerMap.get(packetEntity.getProjectId());
                clientManager.AppendToSend(packetEntity.content);
            }
        } catch (Exception e) {
            log.error(e.getMessage(),e);
        }
        ack.acknowledge();
    }

    @KafkaListener(topics = KafkaProducer.TOPIC_EDGE2CONTROL, groupId = KafkaProducer.TOPIC_CLOUD)
    public void topicEdge2Control(ConsumerRecord<String, String> record, Acknowledgment ack, @Header(KafkaHeaders.RECEIVED_TOPIC) String topic) {
        Optional<String> message = Optional.ofNullable(record.value());
        try {
            if (message.isPresent()) {
                String msg = message.get();
                log.info("topic iot.edge2control------消费了： Topic:" + topic + ",Message:" + msg);
                PacketEntity packetEntity = JSONObject.parseObject(msg, PacketEntity.class);
                IClientManager clientManager = IotClient.clientproject2ControlManagerMap.get(packetEntity.getProjectId());
                if(clientManager != null){
                    clientManager.AppendToSend(packetEntity.content);
                }
            }
        } catch (Exception e) {
            log.error(e.getMessage(),e);
        }
        ack.acknowledge();
    }


}